@@ -16,14 +16,13 @@ def benchit():
              ("Small - High noise", make_data(200, 3.), 100),
              ("Big - Low noise",    make_data(20000, 1), 5),
              ("Big - High noise",   make_data(20000, 2.), 5),
-             ("Plateaus", (0, np.insert(np.ones(20000-3),
-                                        [1000, 10000, -1000], 3)), 5)]
+             ("Plateaus", (0, np.insert(np.ones(20000-3), [1000, 10000, -1000], 3)), 5)]
     for name, data, rep in tests:
         begin = timer()
 
         for _ in range(rep):
             y = data[1] - peakutils.baseline(data[1])
-            if name is "Plateaus": y = data[1]
+            if name == "Plateaus": y = data[1]
             i = peakutils.indexes(y, thres=0.4, min_dist=y.size // 5)
 
         end = timer()
